@@ -349,6 +349,7 @@ go_data_vector_val_load_values (GODataVector *vec)
 	}
 	vec->minimum = minimum;
 	vec->maximum = maximum;
+	vec->len = val->n;
 	vec->base.flags |= GO_DATA_CACHE_IS_VALID;
 }
 
@@ -739,7 +740,7 @@ go_data_vector_str_new (char const * const *str, unsigned n, GDestroyNotify noti
  * @vector: a #GODataVectorStr
  * @func: a #GOTranslateFunc
  * @data: data to be passed to @func and @notify
- * @notify: a #GODestroyNotify function to be called when @vec is
+ * @notify: a #GDestroyNotify function to be called when @vec is
  *   destroyed or when the translation function is changed
  *
  * Sets a function to be used for translating elements of @vec
@@ -864,6 +865,7 @@ go_data_matrix_val_load_values (GODataMatrix *mat)
 	}
 	mat->minimum = minimum;
 	mat->maximum = maximum;
+	mat->size = val->size;
 	mat->base.flags |= GO_DATA_CACHE_IS_VALID;
 }
 
