@@ -45,6 +45,21 @@
 
 #define GOG_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_PLOT, GogPlotClass))
 
+/**
+ * SECTION: gog-plot
+ * @short_description: A plot.
+ * @See_also: #GogChart, #GogSeries
+ *
+ * This is the object that visualizes data.
+ * To manipulate the data shown in the plot, use gog_plot_new_series() and
+ * gog_plot_clear_series()
+ *
+ * Plots are implemented as plug-ins, so make sure the plug-in system is
+ * initialized before trying to create one. See go_plugins_init()
+ *
+ * GOffice ships a number of common plot implementations by default.
+ */
+
 enum {
 	PLOT_PROP_0,
 	PLOT_PROP_VARY_STYLE_BY_ELEMENT,
@@ -508,8 +523,11 @@ gog_plot_update_cardinality (GogPlot *plot, int index_num)
 		/* now add the trend lines if any */
 		children = GOG_OBJECT (series)->children;
 		while (children) {
-			if (GOG_IS_TREND_LINE (children->data))
+			if (GOG_IS_TREND_LINE (children->data)) {
 				j++;
+				if (!gog_trend_line_has_legend (GOG_TREND_LINE (children->data)))
+					no_legend++;
+			}
 			children = children->next;
 		}
 	}
@@ -595,7 +613,8 @@ gog_plot_foreach_elem (GogPlot *plot, gboolean only_visible,
 			/* now add the trend lines if any */
 			children = GOG_OBJECT (ptr->data)->children;
 			while (children) {
-				if (GOG_IS_TREND_LINE (children->data)) {
+				if (GOG_IS_TREND_LINE (children->data) &&
+				    gog_trend_line_has_legend (GOG_TREND_LINE (children->data))) {
 					func (i, go_styled_object_get_style (children->data),
 					      gog_object_get_name (children->data), data);
 					i++;
